ImagePickerResponse class

Image Picker Response class handles data received from Flutter/Native image pickers.

Constructors

ImagePickerResponse.fromJson(Map<String, dynamic> json)
De-serialises to object from Json string
ImagePickerResponse.withImageResponse({String? uri, String? message})
Constructor for Single image response.
ImagePickerResponse.withImagesResponse({List<String>? uris, String? message})
Constructor for Multiple images response.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Use this proeprty to prompt a message if there is any error.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
Use this proeprty when pickImageAsync function is invoked.
getter/setter pair
uris ↔ List<String>?
Use this property when pickImagesAsync function is invoked.
getter/setter pair

Methods

getNonEmptyUris() → List<String>
get the non empty list of string
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
PathsToUris(List<String>? paths) → List<Uri>
helper method to convert list of string paths to list uris
toJson() → Map<String, dynamic>
Serialises object to Json string
toString() → String
A string representation of this object.
inherited
UrisToStringPaths(List<Uri>? uris) → List<String>
helper method to convert list of uris to list string paths

Operators

operator ==(Object other) → bool
The equality operator.
inherited