ScanbotImagePickerFlutter class

Constructors

ScanbotImagePickerFlutter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

platformVersion → Future<String?>
Get the platform version from native side.
no setter

Static Methods

isVersionLessThanIOSFourteen() → Future<bool>
if version is less than iOS 14 for Android return false always true: version is less than 14 false: version is 14 or above
pickImageAsync() → Future<ImagePickerResponse>
pick images from gallery and get the uris list
pickImagesAsync() → Future<ImagePickerResponse>
pick images from gallery and get the uris list